==> owncloud-10.2.0.zip: owncloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Sharing %s failed, because this item is already shared with %s" : "Fallou a compartición de %s, este elemento xa está compartido con %s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Fallou a compartición de %s, non foi posíbel atopar %s,é probábel que o servidor non estea accesíbel.",
    "Accept" : "Aceptar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada do #ownCloud , vexa %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada do #ownCloud",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Open documentation" : "Abrir a documentación",
    "Allow users on this server to send shares to other servers" : "Permitir aos usuarios deste servidor enviar comparticións a outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir aos usuarios deste servidor recibir comparticións de outros servidores",
    "Federated Cloud" : "Nube federada",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it:" : "Compártao:",
    "Share with me via ownCloud" : "Comparte comigo a través do ownCloud",
    "HTML Code:" : "Código HTML:",
    "Add to your ownCloud" : "Engadir ao seu ownCloud",
    "Automatically accept remote shares from trusted servers" : "Aceptar automaticamente os recursos compartidos remotos de servidores de confianza",
    "Federated sharing" : "Compartición federada",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Decline" : "Declinar",
    "Add to your website" : "Engadir ao seu sitio web"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/federatedfilesharing/l10n/gl.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartición federada",
    "Add to your ownCloud" : "Engadir ao seu ownCloud",
    "Invalid Federated Cloud ID" : "ID de nube federada incorrecto",
    "Sharing %s failed, because this item is already shared with %s" : "Fallou a compartición de %s, este elemento xa está compartido con %s",
    "Not allowed to create a federated share with the same user" : "Non está permitido crear un recurso compartido federado co mesmo usuario",
    "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Fallou a compartición de %s, non foi posíbel atopar %s,é probábel que o servidor non estea accesíbel.",
    "Federated Sharing failed: %s" : "Produciuse un fallo na compartición federada: %s",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "%1$s compartiu «%2$s» con vostede (en nome de «%2$s»)",
    "\"%1$s\" shared \"%3$s\" with you" : "%1$s compartiu «%2$s» con vostede",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "«%1$s» convidouno a ver «%3$s» (en nome de «%2$s»)",
    "\"%1$s\" invited you to view \"%3$s\"" : "«%1$s» convidouno a ver «%3$s»",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada do #ownCloud , vexa %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Comparte comigo a través do meu ID da nube federada do #ownCloud",
    "Federated Cloud Sharing" : "Nube federada compartida",
    "Open documentation" : "Abrir a documentación",
    "Allow users on this server to send shares to other servers" : "Permitir aos usuarios deste servidor enviar comparticións a outros servidores",
    "Allow users on this server to receive shares from other servers" : "Permitir aos usuarios deste servidor recibir comparticións doutros servidores",
    "Automatically accept remote shares from trusted servers" : "Aceptar automaticamente os recursos compartidos remotos de servidores de confianza",
    "Federated Cloud" : "Nube federada",
    "Your Federated Cloud ID:" : "ID da súa nube federada:",
    "Share it:" : "Compártao:",
    "Add to your website" : "Engadir ao seu sitio web",
    "Share with me via ownCloud" : "Comparte comigo a través do ownCloud",
    "HTML Code:" : "Código HTML:",
    "Nothing to configure." : "Nada que configurar."
},
"nplurals=2; plural=(n != 1);");
